@@ -1,12 +1,11 @@
-#[macro_use]
-extern crate serde_derive;
-extern crate serde_xml_rs;
-
-#[macro_use]
-extern crate log;
-extern crate simple_logger;
-
+use log::info;
+use serde_derive::Deserialize;
 use serde_xml_rs::from_str;
+use simple_logger::SimpleLogger;
+
+fn init_logger() {
+    let _ = SimpleLogger::new().init();
+}
 
 #[derive(Debug, Deserialize, PartialEq)]
 struct Item {
@@ -16,7 +15,7 @@ struct Item {
 
 #[test]
 fn simple_struct_from_attributes_should_fail() {
-    let _ = simple_logger::init();
+    init_logger();
 
     let s = r##"
         <item name="hello" source="world.rs />
@@ -34,7 +33,7 @@ fn simple_struct_from_attributes_should_fail() {
 
 #[test]
 fn multiple_roots_attributes_should_fail() {
-    let _ = simple_logger::init();
+    init_logger();
 
     let s = r##"
         <item name="hello" source="world.rs" />
